@@ -8,13 +8,14 @@ ArgConfig &ArgConfig::initialize(int accept, char const *optstring,
                 int argc, char **argv,
                 Comment cType, SearchCasing sType, Indices iType)
 {
-    if (s_argconfig)
+    if (s_argConfig)
         throw Exception{} << s_alreadyInitialized;
 
-    s_argconfig = new ArgConfig(accept, optstring,
-                            begin, end,
-                            argc, argv,
-                            cType, sType, iType);
+    s_argConfig.reset(new ArgConfig{ accept, optstring,
+                                     begin, end,
+                                     argc, argv,
+                                     cType, sType, iType }
+                     );
 
-    return *s_argconfig;
+    return *s_argConfig;
 }
