@@ -1,4 +1,4 @@
 inline bool BigInt::isNegative() const
 {
-    return BN_is_negative(&this->d_bn);
+    return BN_is_negative(this->d_bn);
 }
