@@ -32,9 +32,9 @@ char const *DateTime::s_day[] =
 
 mutex DateTime::Zone::s_mutex;
 
-unordered_map<string, unique_ptr<DateTime::Zone>> DateTime::Zone::s_zone;
+unordered_map<string, unique_ptr<DateTime::Zone>> *DateTime::Zone::s_zone = 0;
 
-time_t DateTime::Zone::s_thisZoneShift = DateTime::Zone::initialize();
+time_t DateTime::Zone::s_thisZoneShift;
 
 string DateTime::Zone::s_defaultTZ;
 
