@@ -1,4 +1,2 @@
 inline void DecryptBuf::eoi()
-{
-    eoi_();
-}
+{}
