@@ -1,4 +1,2 @@
 inline void EncryptBuf::eoi()
-{
-    eoi_();
-}
+{}
