@@ -1,5 +1,5 @@
 inline IRandStream::IRandStream(int min, int max)
 :
-    Randbuffer(min, max, 1),
+    RandBuf(min, max, 1),
     std::istream(this)
 {}
