@@ -2,7 +2,7 @@
 
 Log::Log(ostream &out, char const *delim)
 :
-    LogBuffer(out, TIMESTAMPS, true, delim),
+    LogBuf(out, TIMESTAMPS, true, delim),
     ostream(this)
 {
     init();
