@@ -15,14 +15,14 @@
 #include "fsadriver.h"
 
 #ifndef INCLUDED_PATTERN_H_
-#include "../pattern.ih"
+#include "../pattern.hh"
 #endif
 
 using namespace std;
 using namespace FBB;
 
 
-int main(int argc, char **argv, char **envp)
+int main(int argc, char **argv)
 {
     string line;
     PerlSetFSA fsa;
@@ -35,6 +35,4 @@ int main(int argc, char **argv, char **envp)
 
         fsa.convert(line);
     }
-
-    return 0;
 }
